@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.15_02';
+our $VERSION = '0.15_03';
 
 use AnyEvent::Stomper;
 use AnyEvent::Stomper::Error;
@@ -89,7 +89,7 @@ sub execute {
   }
 }
 
-sub get {
+sub get_node {
   my $self = shift;
   my $host = shift;
   my $port = shift;
@@ -824,7 +824,7 @@ Full list of error codes see in documentation on L<AnyEvent::Stomper>.
 
 =head1 OTHER METHODS
 
-=head2 get( $host, $port )
+=head2 get_node( $host, $port )
 
 Gets node by host and port.
 
